==> hplip_1.6.10.orig.tar.gz: hplip-1.6.10/ui/nodevicesform.py <==
# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2006 Hewlett-Packard Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Don Welch
#

from base.g import *
from base import utils
from prnt import cups
import os.path
from qt import *
from nodevicesform_base import NoDevicesForm_base

class NoDevicesForm(NoDevicesForm_base):
    def __init__(self,parent = None,name = None,modal = 0,fl = 0):
        NoDevicesForm_base.__init__(self,parent,name,modal,fl)
        
        self.Icon.setPixmap(QPixmap(os.path.join(prop.image_dir, "warning.png")))
        
    def CUPSButton_clicked(self):
        self.close()
        utils.openURL("http://localhost:631/printers")
        
    def ExitButton_clicked(self):
        self.close()
        
    def setupPushButton_clicked(self):
        self.close()
        
        if utils.which('kdesu'):
            su_sudo = 'kdesu -- %s'
        
        elif utils.which('gksu'):
            su_sudo = 'gksu "%s"'
        
        if utils.which('hp-setup'):
            cmd = su_sudo % 'hp-setup -u'
        else:
            cmd = su_sudo % 'python ./setup.py -u'
        
        log.debug(cmd)
        os.system(cmd)

==> hplip_1.7.3.orig.tar.gz: hplip-1.7.3/ui/nodevicesform.py <==
# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2007 Hewlett-Packard Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Don Welch
#

from base.g import *
from base import utils
from prnt import cups
import os.path
from qt import *
from nodevicesform_base import NoDevicesForm_base

class NoDevicesForm(NoDevicesForm_base):
    def __init__(self,parent = None,name = None,modal = 0,fl = 0):
        NoDevicesForm_base.__init__(self,parent,name,modal,fl)

        self.Icon.setPixmap(QPixmap(os.path.join(prop.image_dir, "warning.png")))

    def CUPSButton_clicked(self):
        self.close()
        utils.openURL("http://localhost:631/admin?op=add-printer")

    def ExitButton_clicked(self):
        self.close()

    def setupPushButton_clicked(self):
        self.close()
        su_sudo = None

        if utils.which('kdesu'):
            su_sudo = 'kdesu -- %s'

        elif utils.which('gksu'):
            su_sudo = 'gksu "%s"'

        if su_sudo is None:
            QMessageBox.critical(self,
                                self.caption(),
                                self.__tr("<b>Unable to find an appropriate su/sudo utility to run hp-setup.</b>"),
                                QMessageBox.Ok,
                                QMessageBox.NoButton,
                                QMessageBox.NoButton)

        else:
            if utils.which('hp-setup'):
                cmd = su_sudo % 'hp-setup -u'
            else:
                cmd = su_sudo % 'python ./setup.py -u'

            log.debug(cmd)
            utils.run(cmd, log_output=True, password_func=None, timeout=1)

            self.parent().RescanDevices()

    def __tr(self,s,c = None):
        return qApp.translate("DevMgr4",s,c)
